package controleur;

/**
 * Ces classes permettent au ControleurVue d'agir comme ActionListener,
 * DocumentListener et ListSelectionListener.
 */
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Observer;

import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;

import modele.Terminal;

/**
 * 
 * @author Franois Caron
 *
 */
public class ControleurVue implements ActionListener, DocumentListener, ListSelectionListener {
	
	/**
	 * Cet attribut sert  stocker le texte.
	 */
	private String texte;
	
	/**
	 * Cet attribut sert  stocker l'index de l'lment slectionn dans une
	 * liste.
	 */
	private int elementSelectionne;
	
	/**
	 * Le Terminal est la classe du modle avec laquelle le contrleur
	 * communique.
	 */
	private Terminal terminal;
	
	/**
	 * Constructeur avec paramtre.
	 * Lors de l'instanciation du contrleur, un observateur (la vue) est pass
	 * en paramtre de faon  ce que le contrleur puisse ajouter l'obervateur
	 * dans le modle.
	 * 
	 * @param observateur
	 */
	public ControleurVue(Observer observateur) {
		terminal = new Terminal(observateur);
		texte = "";
		elementSelectionne = -1;
	}

	@Override
	public void actionPerformed(ActionEvent arg0) {
		/*
		 * Lorsque le bouton de la vue est appuy, cette mthode est invoque.
		 * Pour s'assurer que la mthode traite la bonne action, il faut
		 * vrifier la commande associe  l'action (la commande a t dfinie
		 * au pralable).
		 */
		String action = arg0.getActionCommand();
		if(action.equalsIgnoreCase("AJOUTER")) {
			if(!texte.equals("")) {
				terminal.ajouterString(texte);
			}
		} else if(action.equalsIgnoreCase("RETIRER")) {
			if(elementSelectionne != -1) {
				terminal.retirerString(elementSelectionne);
				/*
				 * Lorsque l'lment slectionn a t retir, il remettre la
				 * valeur  -1
				 */
				elementSelectionne = -1;
			}
		} else {
			System.err.println("L'action '" + action + "' est inconnue...");
		}
	}

	@Override
	public void changedUpdate(DocumentEvent arg0) {
		/*
		 * Cette mthode sert  copier le texte dans la bote de texte de la vue.
		 * 
		 * La mthode "changedUpdate" n'est pas appele directement lorsqu'un
		 * caractre est ajout ou retir de la bote de texte. Ce sont plutt
		 * les mthodes insertUpdate et removeUpdate qui sont invoques.
		 * Cependant, les deux mthodes appellent la mthode changedUpdate, car
		 * le mme traitement est effectu dans les deux cas.
		 */
		Document document = arg0.getDocument();
		try {
			texte = document.getText(0, document.getLength());
		} catch (BadLocationException e) {
			texte = "";
		}
	}

	@Override
	public void insertUpdate(DocumentEvent arg0) {
		changedUpdate(arg0);
	}

	@Override
	public void removeUpdate(DocumentEvent arg0) {
		changedUpdate(arg0);
	}

	@Override
	public void valueChanged(ListSelectionEvent arg0) {
		/*
		 * Lorsque l'utilisateur slectionne un lment dans la liste, le
		 * contrleur note l'index de l'item slectionn.
		 */
		elementSelectionne = arg0.getFirstIndex();
	}

}
