package modele;

/**
 * Ces classes sont utilises pour permettre l'utilisation d'une collection.
 */
import java.util.ArrayList;
import java.util.List;

/**
 * Ces classes sont utilises pour le patron MVC.
 */
import java.util.Observable;
import java.util.Observer;

/**
 * Le Catalogue est le point de mire de la Vue.
 * @author Franois Caron
 *
 */
public class Catalogue extends Observable {

	/**
	 * La collection qui permet de stocker les strings.
	 */
	private List<String> listeStrings;
	
	/**
	 * Constructeur avec paramtre.
	 * Lors de l'instanciation du Catalogue, l'observateur reu est ajout  la
	 * liste des ses observateurs.
	 * @param observateur
	 */
	public Catalogue(Observer observateur) {
		/*
		 * L'attribut de la classe ignore le type exact de List.
		 * Dans le cas prsent, une ArrayList a t utilis. Un autre type de
		 * List aurait fait l'affaire.
		 */
		listeStrings = new ArrayList<String>();
		
		/*
		 * L'observateur reu en paramtre est ajout aux observateurs du
		 * Catalogue.
		 */
		addObserver(observateur);
	}
	
	/**
	 * Cette mthode sert  ajouter une string au Catalogue.
	 * Lors de l'ajout d'une string, les observateurs sont aviss de la 
	 * modification.
	 * @param string
	 */
	public void ajouterString(String string) {
		listeStrings.add(string);
		
		/*
		 * Il est important d'indiquer que la classe observe a chang AVANT
		 * d'aviser les observateurs. 
		 */
		setChanged();
		notifyObservers(listeStrings.toArray());
	}
	
	/**
	 * Cette mthode sert  retirer une string du Catalogue.
	 * Lors du retrait d'une string, les observateurs sont aviss de la
	 * modification.
	 * @param index
	 */
	public void retirerString(int index) {
		listeStrings.remove(index);
		
		/*
		 * Il est important d'indiquer que la classe observe a chang AVANT
		 * d'aviser les observateurs. 
		 */
		setChanged();
		notifyObservers(listeStrings.toArray());
	}
	
}
